----------------------------------------------------------------------------------
--                                 _             _
--                                | |_  ___ _ __(_)__ _
--                                | ' \/ -_) '_ \ / _` |
--                                |_||_\___| .__/_\__,_|
--                                         |_|
--
----------------------------------------------------------------------------------
--
-- Company: hepia
-- Author: Joachim Schmidt <joachim.schmidt@hesge.ch>
--
-- Module Name: aurora_drp_pkg
-- Target Device: SCALP xc7z015clg485-2
-- Tool version: 2019.2
-- Description: DRP interface control signals for the Aurora phy.
--
-- Last update: 2020-10-12
--
---------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

package aurora_drp_pkg is

    constant C_DRP_ADDR_SIZE : integer                                          := 9;
    constant C_DRP_DATA_SIZE : integer                                          := 16;
    constant C_DRP_SEL_SIZE  : integer                                          := 2;
    constant C_DRP_SEL_NORTH : std_ulogic_vector((C_DRP_SEL_SIZE - 1) downto 0) := "00";
    constant C_DRP_SEL_EAST  : std_ulogic_vector((C_DRP_SEL_SIZE - 1) downto 0) := "01";
    constant C_DRP_SEL_SOUTH : std_ulogic_vector((C_DRP_SEL_SIZE - 1) downto 0) := "10";
    constant C_DRP_SEL_WEST  : std_ulogic_vector((C_DRP_SEL_SIZE - 1) downto 0) := "11";

    -- DRP Ports
    -- Master To Slave
    type t_drpm2s is record
        DrpAddrxD : std_ulogic_vector((C_DRP_ADDR_SIZE - 1) downto 0);
        DrpDIxD   : std_ulogic_vector((C_DRP_DATA_SIZE - 1) downto 0);
        DrpEnxS   : std_ulogic;
        DrpWExS   : std_ulogic;
    end record t_drpm2s;

    type t_drpm2s_vector is array (natural range <>) of t_drpm2s;

    -- Slave To Master
    type t_drps2m is record
        DrpDOxD  : std_ulogic_vector((C_DRP_DATA_SIZE - 1) downto 0);
        DrpRdyxS : std_ulogic;
    end record t_drps2m;

    type t_drps2m_vector is array (natural range <>) of t_drps2m;

    type t_drp is record
        M2S : t_drpm2s;
        S2M : t_drps2m;
    end record t_drp;

    constant C_NO_DRP_M2S : t_drpm2s := (DrpAddrxD => (others => '0'),
                                         DrpDIxD   => (others => '0'),
                                         DrpEnxS   => '0',
                                         DrpWExS   => '0');

    constant C_NO_DRP_S2M : t_drps2m := (DrpDOxD  => (others => '0'),
                                         DrpRdyxS => '0');

    constant C_NO_DRP : t_drp := (M2S => C_NO_DRP_M2S,
                                  S2M => C_NO_DRP_S2M);

end package aurora_drp_pkg;
